@@ -32,7 +32,7 @@
 void LoadGraph::clear_background()
 {
 	if (this->background) {
-		g_object_unref(this->background);
+		cairo_surface_destroy (this->background);
 		this->background = NULL;
 	}
 }
@@ -82,12 +82,12 @@ void draw_background(LoadGraph *g) {
 	g->graph_buffer_offset = (int) (1.5 * g->graph_delx) + FRAME_WIDTH ;
 
 	gtk_widget_get_allocation (g->disp, &allocation);
-	g->background = gdk_pixmap_new (GDK_DRAWABLE (gtk_widget_get_window (g->disp)),
-					allocation.width,
-					allocation.height,
-					-1);
-	cr = gdk_cairo_create (g->background);
-	
+        g->background = gdk_window_create_similar_surface (gtk_widget_get_window (g->disp),
+                                                           CAIRO_CONTENT_COLOR,
+                                                           allocation.width,
+                                                           allocation.height);
+	cr = cairo_create (g->background);
+
 	// set the background colour
 	GtkStyle *style = gtk_widget_get_style (ProcData::get_instance()->notebook);
 	gdk_cairo_set_source_color (cr, &style->bg[GTK_STATE_NORMAL]);
@@ -95,13 +95,13 @@ void draw_background(LoadGraph *g) {
 
 	/* draw frame */
 	cairo_translate (cr, FRAME_WIDTH, FRAME_WIDTH);
-	
+
 	/* Draw background rectangle */
 	cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
 	cairo_rectangle (cr, g->rmargin + g->indent, 0,
 			 g->draw_width - g->rmargin - g->indent, g->real_draw_height);
 	cairo_fill(cr);
-	
+
 	cairo_set_line_width (cr, 1.0);
 	cairo_set_dash (cr, dash, 2, 0);
 	cairo_set_font_size (cr, g->fontsize);
@@ -169,7 +169,7 @@ void draw_background(LoadGraph *g) {
 
 /* Redraws the backing buffer for the load graph and updates the window */
 void
-load_graph_draw (LoadGraph *g)
+load_graph_queue_draw (LoadGraph *g)
 {
 	/* repaint */
 	gtk_widget_queue_draw (g->disp);
@@ -191,19 +191,15 @@ load_graph_configure (GtkWidget *widget,
 
 	g->clear_background();
 
-	if (g->gc == NULL) {
-		g->gc = gdk_gc_new (GDK_DRAWABLE (gtk_widget_get_window (widget)));
-	}
-
-	load_graph_draw (g);
+	load_graph_queue_draw (g);
 
 	return TRUE;
 }
 
 static gboolean
-load_graph_expose (GtkWidget *widget,
-		   GdkEventExpose *event,
-		   gpointer data_ptr)
+load_graph_draw (GtkWidget *widget,
+                 cairo_t * context,
+                 gpointer data_ptr)
 {
 	LoadGraph * const g = static_cast<LoadGraph*>(data_ptr);
 	GtkAllocation allocation;
@@ -212,18 +208,15 @@ load_graph_expose (GtkWidget *widget,
 	guint i, j;
 	gdouble sample_width, x_offset;
 
-	if (g->background == NULL) {
-		draw_background(g);
-	}
-
 	window = gtk_widget_get_window (g->disp);
 	gtk_widget_get_allocation (g->disp, &allocation);
-	gdk_draw_drawable (window,
-			   g->gc,
-			   g->background,
-			   0, 0, 0, 0, 
-			   allocation.width,
-			   allocation.height);
+
+	if (g->background == NULL) {
+		draw_background(g);
+                cairo_pattern_t * pattern = cairo_pattern_create_for_surface (g->background);
+		gdk_window_set_background_pattern (window, pattern);
+                cairo_pattern_destroy (pattern);
+        }
 
 	/* Number of pixels wide for one graph point */
 	sample_width = (float)(g->draw_width - g->rmargin - g->indent) / (float)LoadGraph::NUM_POINTS;
@@ -252,7 +245,7 @@ load_graph_expose (GtkWidget *widget,
 		for (i = 1; i < LoadGraph::NUM_POINTS; ++i) {
 			if (g->data[i][j] == -1.0f)
 				continue;
-			cairo_curve_to (cr, 
+			cairo_curve_to (cr,
 				       x_offset - ((i - 0.5f) * g->graph_delx),
 				       (1.0f - g->data[i-1][j]) * g->real_draw_height + 3.5f,
 				       x_offset - ((i - 0.5f) * g->graph_delx),
@@ -567,7 +560,7 @@ load_graph_update (gpointer user_data)
 	}
 
 	if (g->draw)
-		load_graph_draw (g);
+		load_graph_queue_draw (g);
 
 	g->render_counter++;
 
@@ -619,7 +612,6 @@ LoadGraph::LoadGraph(guint type)
     graph_buffer_offset(0),
     main_widget(NULL),
     disp(NULL),
-    gc(NULL),
     background(NULL),
     timer_index(0),
     draw(FALSE),
@@ -676,9 +668,9 @@ LoadGraph::LoadGraph(guint type)
 	case LOAD_GRAPH_MEM:
 		g->colors[0] = ProcData::get_instance()->config.mem_color;
 		g->colors[1] = ProcData::get_instance()->config.swap_color;
-		g->mem_color_picker = gsm_color_button_new (&g->colors[0], 
+		g->mem_color_picker = gsm_color_button_new (&g->colors[0],
 							    GSMCP_TYPE_PIE);
-		g->swap_color_picker = gsm_color_button_new (&g->colors[1], 
+		g->swap_color_picker = gsm_color_button_new (&g->colors[1],
 							     GSMCP_TYPE_PIE);
 		break;
 	case LOAD_GRAPH_NET:
@@ -697,8 +689,8 @@ LoadGraph::LoadGraph(guint type)
 
 	g->disp = gtk_drawing_area_new ();
 	gtk_widget_show (g->disp);
-	g_signal_connect (G_OBJECT (g->disp), "expose_event",
-			  G_CALLBACK (load_graph_expose), g);
+	g_signal_connect (G_OBJECT (g->disp), "draw",
+			  G_CALLBACK (load_graph_draw), g);
 	g_signal_connect (G_OBJECT(g->disp), "configure_event",
 			  G_CALLBACK (load_graph_configure), g);
 	g_signal_connect (G_OBJECT(g->disp), "destroy",
